%define desktop_file_utils_version 0.2.90

# Use --without modular_x to rebuild without modular X deps
%define _modular_x 0%{!?_without_modular_x:1}

%if %{?fedora}%{!?fedora:7} >= 7
%define _opengl_wrapper 1
%else
%define _opengl_wrapper 0
%endif

Summary: 3D racing game featuring Tux
Name: extremetuxracer
Version: 0.4
Release: 13%{?dist}
License: GPLv2+
Group: Amusements/Games
URL: http://extremetuxracer.com
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Source0: http://downloads.sourceforge.net/extremetuxracer/extremetuxracer-%{version}.tar.gz
Source1: etracer.desktop

# ET 0.4 isn't really maintained upstream anymore, therefore patches aren't
# submitted upstream as the code base has diverged too much

# https://bugzilla.redhat.com/show_bug.cgi?id=652913
# Fix crash in race selection screen when random keys are pressed
Patch0: extremetuxracer-0.4-random-keypress-crash.patch

# Build with newer libpng versions, modifies configure.ac
Patch1: extremetuxracer-0.4-libpng.patch

# Call memset() with correctly ordered parameters
Patch2: extremetuxracer-0.4-memset.patch

# Changes from rebuilding files with autoreconf
Patch10: extremetuxracer-0.4-7-autoreconf.patch.bz2

Obsoletes: tuxracer <= 0.61
Obsoletes: ppracer <= 0.3.1

%if %_modular_x
BuildRequires: libICE-devel
BuildRequires: libSM-devel
BuildRequires: libX11-devel
BuildRequires: libXi-devel
BuildRequires: libXext-devel
BuildRequires: libXmu-devel
BuildRequires: libXt-devel
%else
BuildRequires: xorg-x11-devel
%endif
BuildRequires: libGL-devel
BuildRequires: libGLU-devel
BuildRequires: SDL-devel >= 1.2
BuildRequires: SDL_mixer-devel >= 1.2
BuildRequires: tcl-devel >= 8.4.9
BuildRequires: freetype-devel
BuildRequires: libpng-devel
BuildRequires: pkgconfig
BuildRequires: desktop-file-utils >= %{desktop_file_utils_version}
BuildRequires: fontpackages-devel
BuildRequires: symlinks

%if %_opengl_wrapper
Requires: opengl-games-utils
%endif
Requires: extremetuxracer-common = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: extremetuxracer-papercuts-fonts = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: extremetuxracer-papercuts-outline-fonts = %{?epoch:%{epoch}:}%{version}-%{release}

%description
Extreme Tux Racer is an open-source downhill racing game starring Tux, the
Linux mascot.

%package common
Summary: Common files for Extreme Tux Racer and its fonts
BuildArch: noarch

%description common
This package consists of files used by other %{name} packages.

%package papercuts-fonts
Summary: PaperCuts 2.0 font
BuildArch: noarch
Requires: extremetuxracer-common = %{?epoch:%{epoch}:}%{version}-%{release}

%description papercuts-fonts
This package contains the PaperCuts 2.0 font which is used by Extreme Tux
Racer.

%_font_pkg -n papercuts PaperCuts20.ttf

%package papercuts-outline-fonts
Summary: PaperCuts Outline 2.0 font
BuildArch: noarch
Requires: extremetuxracer-common = %{?epoch:%{epoch}:}%{version}-%{release}

%description papercuts-outline-fonts
This package contains the PaperCuts Outline 2.0 font which is used by Extreme
Tux Racer.

%_font_pkg -n papercuts-outline PaperCuts_outline.ttf

%prep
%setup -q

%patch0 -p1 -b .random-keypress-crash
%patch1 -p1 -b .libpng
%patch2 -p1 -b .memset

%patch10 -p1 -b .autoreconf

%build
%configure --with-tcl=%{_libdir}
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR="%{buildroot}" install

mkdir -p %{buildroot}%{_datadir}/pixmaps/
install -m 0644 etracericon.svg %{buildroot}%{_datadir}/pixmaps/

%if %_opengl_wrapper
ln -snf opengl-game-wrapper.sh %{buildroot}%{_bindir}/etracer-wrapper
sed 's:^Exec=\(.*\)$:Exec=\1-wrapper:g' < %{SOURCE1} > etracer.desktop
%else
cp -dpf %{SOURCE1} etracer.desktop
%endif

mkdir -p %{buildroot}%{_datadir}/applications/
desktop-file-install --dir %{buildroot}%{_datadir}/applications \
    etracer.desktop

mkdir -p %{buildroot}%{_fontdir}
pushd %{buildroot}%{_datadir}/etracer/fonts
for i in *.ttf; do
    mv "$i" %{buildroot}%{_fontdir}/
    ln -s "%{buildroot}%{_fontdir}/$i" "$i"
done
symlinks -c -s .
popd

%clean
rm -rf %{buildroot}

%files
%defattr (-, root, root, 755)
%doc contrib
%{_bindir}/etracer
%if %_opengl_wrapper
%{_bindir}/etracer-wrapper
%endif
%{_datadir}/etracer
%{_datadir}/pixmaps/etracericon.svg
%{_datadir}/applications/etracer.desktop

%files common
%defattr (-, root, root, 755)
%doc AUTHORS COPYING ChangeLog

%changelog
* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Mar 08 2013 Jon Ciesla <limburgher@gmail.com> - 0.4-12
- Drop desktop vendor tag.

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-9
- Rebuilt for c++ ABI breakage

* Tue Jan 10 2012 Nils Philippsen <nils@redhat.com> - 0.4-8
- rebuild for gcc 4.7

* Wed Nov 09 2011 Nils Philippsen <nils@redhat.com> - 0.4-7
- comment patches
- patch and rebuild for libpng-1.5
- fix use of memset()

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Nov 15 2010 Nils Philippsen <nils@redhat.com> 0.4-5
- don't call null members (#652913)

* Mon Nov 15 2010 Nils Philippsen <nils@redhat.com> 0.4-4
- rebuild against new toolchain

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Nils Philippsen <nils@redhat.com> 0.4-2
- package fonts separately to comply with font packaging guidelines (#477383)

* Wed Mar 05 2008 Nils Philippsen <nphilipp@redhat.com> 0.4-1
- Package Review (#436126):
  - remove BR: sed, zlib-devel
  - add BR: pkgconfig
  - use icon name without extension in desktop file

* Wed Mar 05 2008 manuel wolfshant <wolfy@fedoraproject.org>
- add --with-tcl=... to %%configure line

* Wed Mar 05 2008 Nils Philippsen <nphilipp@redhat.com> 0.4-0
- version 0.4
- initial packaging based on ppracer
